@@ -1,7 +1,7 @@
 //#define XERR
 #include "costs.ih"
 
-uint16_t Costs::cost(double diameter) const
+size_t Costs::cost(double diameter) const
 {
                     // reversed search: start at the max. diameter
     return find_if(d_treatmntPair.rbegin(), d_treatmntPair.rend(),
