@@ -3,7 +3,7 @@ inline double Costs::usingAt(double age) const
     return discount(age, d_usingCosts);
 }
 
-inline double Costs::screening(double age, uint16_t cost) const
+inline double Costs::screening(double age, size_t cost) const
 {
     return discount(age, cost);
 }
