@@ -39,13 +39,15 @@ enum DistType                   // Distribution::s_name when modified
 {
     UNIFORM,                    // always used distributions
     UNIFORM_CASE,
+    UNIFORM_VSD,
     LOGNORMAL,
 
     N_STD_DISTRIBUTIONS,
- 
+
     NORMAL_VARY = N_STD_DISTRIBUTIONS,
 
     UNIFORM_VARY,
+    UNIFORM_VSD_VARY,
     LOGNORMAL_VARY,
 
     BETA_VARY,                  // only used when parameter spead
@@ -60,11 +62,17 @@ enum GeneratorType
     RANDOM_SEED,
 };
 
-enum ParamsSrc         
+enum ParamsSrc
 {
     CONFIGFILE,
     ANALYSIS,
     NONE,
 };
 
+enum Series         // see (Prob)Group
+{
+    RANGE,          // e.g., 0 - 40:
+    SINGLE,         // e.g.,   20
+};
+
 #endif
