@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "growth.ih"
 
 void Growth::setSelfDetect()
