@@ -7,5 +7,6 @@ xerr("costs: " << cost);
 
     d_caseCost += cost;
 
-    d_roundCost[d_round] += round(cost);        // round(): cmath
+                                            // round() is the cmath::round
+    d_roundCost[d_round] += round(cost);    // function
 }
