@@ -19,8 +19,8 @@ void Loop::caseInit()
     d_indices = cptIndices();   // LC simulation: 0-vector
 
     //xerr("cumTotalRisk");
-    d_tumorInfo.cumTotalRisk(
-                    d_screening.radiationRisk(
+    d_tumorInfo.cumTotalRisk(                   // 24/1 also sets the attended 
+                    d_screening.radiationRisk(  // 24/1 flag
                             d_modalities,
                             d_indices,
                             d_tumorInfo.beir7().beta(),
