@@ -7,7 +7,8 @@ void Loop::characteristics(Status natural, Status tumor)
 {
 
                                 // the tumor was self-detected: determine
-    d_tumor.characteristics();  // its characteristics
+                                // its characteristics
+    d_tumor.characteristics(d_tumor.selfDetectAge());  
 
     d_selfDetected = true;
 
