@@ -13,23 +13,23 @@ Uint16Vect Loop::cptIndices() const
     else                        // for BC: compute the indices used to obtain
     {                           //         dose values
         double prob = Random::instance().uniform();
-    
+
         for (double age: d_screening.ages())
         {
-                    // d_groupVector initialized at the constructor to 
+                    // d_groupVector initialized at the constructor to
                     // the LC s3 table or the Densities biRad vector.
-            size_t idx = ProbGroup::probIndexOf(*d_groupVector, age, prob);
-    
-            if (idx == string::npos)                        // invalid age   
-                    throw Exception{} << 
+            RowCol rowCol = ProbGroup::probIndexOf(*d_groupVector, age, prob);
+
+                                                        // invalid age
+            if (rowCol.first == static_cast<uint16_t>(string::npos))
+                    throw Exception{} <<
                                 "runtime-error: no age category for age " <<
                                 age;
-    
+
                     // store the birad/s3 column index to use for prob/age:
-            ret.push_back(idx);
+            ret.push_back(rowCol.first);
         }
     }
 
     return ret;
-
 }
