@@ -26,16 +26,16 @@ class Loop: public Globals
 {
     enum Status
     {
-        PRESENT,
-        LEFT_PRE,           // left the pre, during, post screening
-        LEFT_DURING,
-        LEFT_POST,
-        TUMOR_PRE,
-        TUMOR_DURING,
-        TUMOR_POST,
+        PRESENT,            // 0
+        LEFT_PRE,           // 1 left the pre, during, post screening
+        LEFT_DURING,        // 2
+        LEFT_POST,          // 3
+        TUMOR_PRE,          // 4
+        TUMOR_DURING,       // 5
+        TUMOR_POST,         // 6
     };
 
-    enum                    // round info (per case)
+    enum                    // round info (per case) '0': not attended
     {
         ATTENDED        = '1',
         FALSE_NEGATIVE  = '2',
@@ -72,7 +72,7 @@ class Loop: public Globals
     double d_naturalDeathAge = 0;      // dying age w/o tumor
     double d_deathAge = 0;             // actual dying age
 
-    uint16_t d_nRounds;
+    uint16_t d_nRounds;                 // from Screening::nRounds()
     uint16_t d_round = 0;               // currently used screening round
 
     std::string d_roundInfo;
@@ -124,7 +124,10 @@ class Loop: public Globals
         FBB::CSVTable headerData(size_t iter) const;
         FBB::CSVTable headerRounds(size_t iter) const;
         FBB::CSVTable headerSensitivity() const;
-        void intervalCancer();
+
+//        void removeCase(double screeningAge, double selfDetectAge);
+        void intervalCancer(double screeningAge);
+
         void labels(std::ostream &out) const;
         bool leaving(double screeningAge);
         void maybeDetect(ModBase *modBase, double screeningAge);
