@@ -9,7 +9,8 @@ Loop::Loop(StringVect const &labels)
     d_modalities(d_tumor),
     d_screening(d_modalities),
     d_nRounds(d_screening.nRounds()),
-    d_timestamp(DateTime{ DateTime::LOCALTIME }.rfc2822())
+    d_timestamp(DateTime{ DateTime::LOCALTIME }.rfc2822()),
+    d_tnm(d_options.tnm() ? &fillTNM : &noTNM)
 {
     if (Globals::isBreast())
         d_groupVector = d_densities.biRad();
