@@ -11,13 +11,22 @@ void Loop::maybeFalsePositive(ModBase *modBase, double screeningAge)
 //xerr("specificity: " << modBase->specificity(screeningAge) << ' ' << \ <--
 //d_costs.usingAt(screeningAge));
 
-    if (Random::instance().uniform() > modBase->specificity(screeningAge))
+    double rnd = Random::instance().uniform();
+    double spec = modBase->specificity(screeningAge);
+
+    if (rnd <= spec)
+        g_log << "      " << rnd << " <= specificity(" <<
+                screeningAge << ") = " << spec << ": no false positive\n";
+    else
     {
+        g_log << "      " << rnd << " > specificity(" <<
+                screeningAge << ") = " << spec << ": false positive\n";
+
         modBase->falsePositive();
         ++d_nRoundFP[d_round];
         d_roundInfo[d_round] = FALSE_POSITIVE;
 
-        addCost(d_costs.usingAt(screeningAge)); 
-//        addCost(d_costs.biopsy(screeningAge)); 
+        addCost(d_costs.usingAt(screeningAge));
+//        addCost(d_costs.biopsy(screeningAge));
     }
 }
