@@ -11,29 +11,25 @@ void Loop::postScreen()
 
     g_log << "\nLoop::postScreen\n";
 
-
-//if (g_caseIdx >= g_err) xerr(g_caseIdx << " treatment cost entry: " << d_caseCost);
-
                                     // there may be a tumor, detected before
                                     // the woman's natural death
     if (
-        d_tumor.selfDetectable() and
-            d_tumor.selfDetectAge() < d_naturalDeathAge
+        d_tumor.selfDetectable()
+        and d_tumor.selfDetectAge() < d_naturalDeathAge
     )
     {
-        //if (g_caseIdx >= g_err) xerr(g_caseIdx << " treatmentDeath");
         g_log << "  *** case died because of a tumor detected at age " <<
                  d_tumor.selfDetectAge() << '\n';
 
         treatmentDeath();           // this results in a tumor caused death.
                                     // (the condition check in the original
     }                               //  sources is superfluous)
-    else                            // or a naturally caused death
+    else                        // or a naturally caused death
     {
         //if (g_caseIdx >= g_err)xerr(g_caseIdx << " setStatus");
         setStatus(LEFT_POST, d_naturalDeathAge);
         g_log << "  *** case died at natural death age " <<
-                    d_naturalDeathAge << '\n';
+                                                d_naturalDeathAge << '\n';
 
                                     // although the woman has died, still
                                     // determine the tumor's characteristics
@@ -41,3 +37,9 @@ void Loop::postScreen()
             d_tumor.characteristics(d_deathAge);
     }
 }
+
+
+//if (g_caseIdx >= g_err) 
+//xerr(g_caseIdx << " treatment cost entry: " << d_caseCost);
+
+//if (g_caseIdx >= g_err) xerr(g_caseIdx << " treatmentDeath");
