@@ -7,7 +7,7 @@ void Loop::screen(double screeningAge)
 {
     // visit all modalities: for (ModBase *...) or comparable
 
-    g_log << "    Loop::screen\n";
+    g_log << __FILE__ " screen at age " << screeningAge << "\n";
 
                                             // org/screen: 4, screen.txt: 1
     for (ModBase *modBase:
@@ -26,11 +26,9 @@ void Loop::screen(double screeningAge)
         if (d_tumor.selfDetectable())
             d_tumor.characteristics(screeningAge);
 
+                        // Org. 2nd term: screeningAge >= d_tumor.onset())
                         // test2 (see below)
-        if (
-            d_tumor.selfDetectable() and
-            screeningAge >= d_tumor.detectableAge()
-        )
+        if (d_tumor.selfDetectable() and d_tumor.onset() <= screeningAge)
             maybeDetect(modBase, screeningAge);
         else
             maybeFalsePositive(modBase, screeningAge);
