@@ -3,7 +3,7 @@ inline StringVect &ModBase::base()
     return d_base;
 }
 
-inline uint16_t ModBase::cost() const
+inline size_t ModBase::cost() const
 {
     return d_cost;
 }
@@ -28,11 +28,6 @@ inline std::string const &ModBase::id() const
     return d_id;
 }
 
-//inline VSDvect const *ModBase::dose() const
-//{
-//    return vDose();
-//}
-
 inline double ModBase::dose(uint16_t idx) const
 {
     return vDose(idx);
@@ -58,12 +53,3 @@ inline void ModBase::vary(std::ostream &out)
     return vVary(out);
 }
 
-//inline void ModBase::count(std::ostream &out, size_t round) const
-//{
-//    out << ',' << std::setw(7) << d_count[round];
-//}
-
-//inline void ModBase::roundHeader(std::ostream &out) const
-//{
-//    out << ", #" << d_id;
-//}
