@@ -22,7 +22,7 @@ class ModBase
 
     bool d_defined;
 
-    uint16_t d_cost = 0;                        // cost of using th modality
+    size_t d_cost = 0;                        // cost of using th modality
     SizeVect d_count;
     uint16_t d_falsePositives;
 
@@ -31,9 +31,8 @@ class ModBase
 
         virtual ~ModBase();
 
-        uint16_t cost() const;                                      // .f
+        size_t cost() const;                                        // .f
         void count(size_t round);                                   // .f
-//        VSDvect const *dose() const;                                // .f
         bool defined() const;                                       // .f
         double dose(uint16_t idx) const;                            // .f
         void falsePositive();                                       // .f
