@@ -3,5 +3,5 @@
 
 double MRI::vSensitivity(size_t idx) const
 {
-    return d_sensitivity;
+    return d_sensitivity.value();
 }
