@@ -3,5 +3,5 @@
 
 double MRI::vSpecificity(double age) const
 {
-    return d_specificity;
+    return d_specificity.value();
 }
