@@ -1,26 +1,26 @@
 //#define XERR
 #include "parser.ih"
 
-    // In the configuration file specifications are just lines. Each keyword 
+    // In the configuration file specifications are just lines. Each keyword
     // must therefore be searched via a unique path. So searching for
-    // e.g., { 'costs:' } returns multiple hits, but searching for 
+    // e.g., { 'costs:' } returns multiple hits, but searching for
     // { 'Scenario:', 'costs:' } returns only one hit
 
     // Named MapValues must be used only once. E.g., for Mammo 'Dose' is
     // specified by mdose, for Tomo it is specified by tdose.
     // final "named" keys are always unique and can be specified at MapValue
-    // specifications. 
+    // specifications.
 
     // see also the description at the end of this file
 
-        
+
 namespace {
 
 
 Parser::MapValue scenario
 {
-    "Scenario:", 
-    new Parser 
+    "Scenario:",
+    new Parser
     {
         { // map
             {"spread:",     new Parser },
@@ -35,8 +35,8 @@ Parser::MapValue scenario
 
 Parser::MapValue screening
 {
-    "Screening:", 
-    new Parser 
+    "Screening:",
+    new Parser
     {
         { // map
             {"round:",              new Parser },
@@ -47,8 +47,8 @@ Parser::MapValue screening
 
 Parser::MapValue breastDensities
 {
-    "BreastDensities:", 
-    new Parser 
+    "BreastDensities:",
+    new Parser
     {
         { // map
             {"ageGroup:", new Parser},
@@ -115,7 +115,7 @@ Parser::MapValue ct
 
 Parser::MapValue modalities
 {
-    "Modalities:", 
+    "Modalities:",
     new Parser
     {
         { // map
@@ -277,7 +277,7 @@ Parser::MapValue tumBeir7
 
 Parser::MapValue tumor
 {
-    "Tumor:", 
+    "Tumor:",
     new Parser
     {
         { // map
@@ -287,6 +287,7 @@ Parser::MapValue tumor
             { "beir7:",     new Parser },
             tumSurvival,
             s3,
+            { "bc:",        new Parser },
         }
     }
 };
@@ -305,7 +306,7 @@ Parser::MapValue cosDiscount
 
 Parser::MapValue costs
 {
-    "Costs:", 
+    "Costs:",
     new Parser
     {
         {
@@ -318,7 +319,7 @@ Parser::MapValue costs
 
 } // namespace
 
-Parser::Map Parser::s_map       // see the configuration file: these are the 
+Parser::Map Parser::s_map       // see the configuration file: these are the
 {                               // configurations for the top-level keywords
     scenario,                   // e.g., scenario here (above) and Scenario:
     costs,                      // in the configuration file
@@ -329,35 +330,35 @@ Parser::Map Parser::s_map       // see the configuration file: these are the
 };
 
 
-//  By convention, keywords of lines mererly containing the keyword 
-//  start with capitals, and those followed by actual parameter values 
+//  By convention, keywords of lines mererly containing the keyword
+//  start with capitals, and those followed by actual parameter values
 //  start with lower-case letters
-//  
-//  MapValue definitions ending in 'new Parser' match one or more 
+//
+//  MapValue definitions ending in 'new Parser' match one or more
 //  configuration lines which are handled by the objects for which
 //  the configuration line is intended.
-//  
+//
 //  Parser specifications merely consisting of identifiers refer to
 //  separately defined specifications
-//  
-//  E.g., 
-//  
+//
+//  E.g.,
+//
 //      Parser::MapValue modalities
 //      {
-//          "Modalities:", 
+//          "Modalities:",
 //          new Parser
 //          {
-//              { 
+//              {
 //                  mammo,
 //                  tomo,
 //                  mri
 //              }
 //          }
 //      };
-//  
+//
 //  specifies Modalities: as a keyword, followed by the definitions of mammo,
 //  tomo, and mri. The 'tomo' MapValue is
-//  
+//
 //      Parser::MapValue tomo
 //      {
 //          "Tomo:",
@@ -370,10 +371,10 @@ Parser::Map Parser::s_map       // see the configuration file: these are the
 //              }
 //          }
 //      };
-//  
+//
 //  and so 'costs:' is followed by >= 1 parameter values, but 'dose' is
-//  specified separately:    
-//  
+//  specified separately:
+//
 //      Parser::MapValue dose
 //      {
 //          "Dose:",
@@ -384,10 +385,10 @@ Parser::Map Parser::s_map       // see the configuration file: these are the
 //              }
 //          }
 //      };
-//  
+//
 //  The keyword 'Dose:' is on a line by itself, followed by lines starting
-//  with 'bi-rad:' containing parameter specifications. 
-//  
+//  with 'bi-rad:' containing parameter specifications.
+//
 //  What the parameter specifications are is determined by the objects parsing
 //  the configuration lines. E.g., ageGroup: is specified as
 //          ageGroup:   0 - 40:     .961        .005   Normal
