@@ -35,8 +35,8 @@ class ProbGroup
     {
         N_PROBCATS = 4,   // # of probability categories
     };
-
-    Group   d_group;
+                                            // cf Group::extract(). begin() 
+    Group   d_group;                        // not used, end() is inclusive
 
     std::vector<double> d_prob;
     std::vector<double> d_cumProbs;
