@@ -1,10 +1,12 @@
 //#define XERR
 #include "scenario.ih"
 
-void Scenario::checkCumDeath(string const &source) const
+void Scenario::checkCumDeath(string const &source,
+                             LineInfo const *previous) const
 {
     if (size_t size = d_cumDeathProportions.size(); size != END_AGE)
     {
+        previous = showLineInfo(previous);
         Err::msg(Err::CUM_DEATH) <<  source << "): " <<
                                     END_AGE << " proportions required, " <<
                                     size << " specified" << endl;
@@ -16,8 +18,11 @@ void Scenario::checkCumDeath(string const &source) const
                 ++iter, ++next)
     {
         if (*next < *iter)
+        {
+            previous = showLineInfo(previous);
             Err::msg(Err::CUM_DEATH) << source << ") proportions decrease: " <<
                     (next - begin) << " (" << *next << ") less than " <<
                     (iter - begin) << " (" << *iter << ')' << endl;
+        }
     }
 }
