@@ -37,8 +37,9 @@ class Screening
     Modalities const &d_modalities;
 
     StringVect d_base;
-
-    RoundVect d_roundVect;
+                                            // this vector's size holds the
+    RoundVect d_roundVect;                  // #rounds
+    BoolVect d_attend;                      // true: case attends the round
 
                                             // attendance rate, configured at
     double d_rate;                          // Screening: attendanceRate:
@@ -55,7 +56,7 @@ class Screening
 
         double rate() const;                                            // .f
 
-        DoubleVect radiationRisk(
+        DoubleVect radiationRisk(           // 24/1 also sets d_attend's values
                             Modalities const &modalities,
                             Uint16Vect const &indices,
                             double beta, double eta);     // beir7 values
@@ -70,6 +71,8 @@ class Screening
 
         void writeParameters(std::ostream &out) const;
 
+        bool attend(size_t idx) const;  // 24/1 true: case attended this round
+
     private:
         bool addModality(std::istream &in, Round &round);
                                             // false: round: none, noneLine
