@@ -11,6 +11,6 @@ Screening::Screening(Modalities const &modalities)
     d_errRiskVector(Arg::instance().option('e') ? errRisk1404 : errRisk1405),
     d_lungCancer(not Globals::isBreast())
 {
-    setAttendanceRate();
-    setRounds();
+    setAttendanceRate();            // from the config file
+    setRounds();                    // from the config file
 }
