@@ -1,13 +1,10 @@
-//#define XERR
+#define XERR
 #include "survival.ih"
 
-extern size_t g_caseIdx;
-extern size_t g_err;
-
-    // determine the row of d_vsdMatrix to use by finding the rowindex in s3
-    // containing 'diameter' and then computing the lowest column index
-    // in that row exceeding a random proportion value. That index becomes
-    // d_vsdRow.
+    // determine the row of d_vsdMatrix to use by locating the row in s3
+    // containing 'diameter' in its ProbGrooup.end() value. Then compute
+    // the lowest column index in that row exceeding a random proportion
+    // value. That index becomes d_vsdRow.
 RowCol Survival::cptVSDrow(double diameter)
 {
     // if diameter > 100 the last line in S3 must be used. probIndexOf uses
@@ -23,13 +20,9 @@ RowCol Survival::cptVSDrow(double diameter)
                                     Random::instance().uniformVSD()
                                 );
 
-    d_vsdRow = rowCol.first;
+    d_vsdRow = rowCol.second;
 
     g_log << "      Survival::cptVSDRow: S3 row = " << d_vsdRow <<
                                         " for diameter " << diameter << '\n';
-
     return rowCol;
 }
-
-//                                    Random::instance().uniform()
-//                                    Random::instance().uniformCase()
