@@ -16,17 +16,16 @@ Survival::Survival()
     {
         d_vary = &Survival::varyBreast;
         d_write = &Survival::writeBreast;
-        d_cptVSDrow = &Survival::noop;
+        d_cptVSDrow = &Survival::cptTNM;
 
         d_vsdMatrix.push_back(                  // load the BC 'type' params
                         Parser::VSDparameters(
-                            VARY_MEAN, 
+                            VARY_MEAN,
                             { "Tumor:", "Survival:", "type:" },
                             { 'a', 'b', 'c', 'd' }
                         )
                     );
+
+        loadBC();
     }
 }
-
-
-
