@@ -12,7 +12,7 @@ extern size_t g_err;
 
 void Tumor::setDeathAge(double detectionAge)
 {
-    check("death age");
+    requireTumor("death age");
 
     // interval halving: search between 0 and 100
     double low = 0;
