@@ -3,9 +3,9 @@ inline double Tumor::selfDetectAge() const
     return d_selfDetectAge;
 }
 
-inline double Tumor::detectableAge() const
+inline double Tumor::onset() const
 {
-    return d_detectableAge;
+    return d_onset;
 }
 
 inline bool Tumor::selfDetectable() const
@@ -13,10 +13,10 @@ inline bool Tumor::selfDetectable() const
     return d_selfDetectAge != NO_TUMOR;
 }
 
-inline void Tumor::characteristics()
-{
-    characteristics(d_selfDetectAge);
-}
+// inline void Tumor::characteristics()
+// {
+//     characteristics(d_selfDetectAge);
+// }
 
 inline void Tumor::intervalCancer()
 {
@@ -48,6 +48,11 @@ inline bool Tumor::metastasis() const
     return d_survival.metastatis();
 }
 
+inline bool Tumor::present() const
+{
+    return d_present;
+}
+
 inline std::ostream &operator<<(std::ostream &out, Tumor const &tumor)
 {
     return tumor.insert(out);
@@ -57,3 +62,4 @@ inline RowCol const &Tumor::rowCol() const
 {
     return d_rowCol;
 }
+
