@@ -44,11 +44,11 @@ class Tumor: public Globals
     double d_deathAge;      // death age because of the tumor
     double d_prePeriod;     // _preclin... #years before d_selfDetectAge
 
-                                // the age where a tumor is potentially
-                                // detectable on mammographic screening.
-                                // From this age onward it'll grow.
-                                // (originally called _preclinAge)
-    double d_detectableAge;     // (d_selfDetectAge - d_prePeriod)
+                                // the age where a tumor starts to grow and is
+                                // potentially detectable on mammographic
+                                // screening.  From this age onward it'll
+                                // grow.  (originally called _preclinAge)
+    double d_onset;         // (d_selfDetectAge - d_prePeriod)
 
 
     double d_pSurvival;     // p(Survival) after treatment
@@ -77,24 +77,26 @@ class Tumor: public Globals
         bool selfDetectable() const;        // true: tumor selfDetectable .f
 
         double selfDetectAge() const;       // self-detect age          .f
-        double deathAge() const;                                    //  .f
-        double detectableAge() const;                               //  .f
+        double deathAge() const;            // tumor-caused death age   .f
+        double onset() const;                               //  .f
 
         double volume() const;
         double diameter() const;                                    // .f
 
         bool metastasis() const;            // only with lung cancer    .f
 
-                                            // cpt the tumor's diameter and
-                                            // volume:
+                    // cpt the tumor's diameter and volume at 'age',
+                    // using the age - d_onset time interval
         void   characteristics(double age); // at 'age'                 // .cc
-        void   characteristics();           // at d_selfDetectAge       // .f
+        // void   characteristics();           // at d_selfDetectAge       // .f
 
         void intervalCancer();                                      // .f
 
                                             // tumor found during
         void found();                       // the screening        // .f
 
+        bool present() const;                                       // .f
+
         void setDeathAge();                 // wrt d_selfDetectAge  // .f
         void setDeathAge(double refAge);    // wrt reference age
 
@@ -106,7 +108,7 @@ class Tumor: public Globals
         std::ostream &insert(std::ostream &out) const;
 
         bool tumorAge();                    // false: no tumor
-        void check(char const *type) const;
+        void requireTumor(char const *type) const;
         uint16_t ageGroup() const;                                  // .ih
 
         double functionF(double years) const;
